# CCRS

The CCRS is a python package that could provide individual risk stratification of coronary heart disease and ischemic stroke in batches.


## Installation and dependency package
 dependency package	
```
python >=3.7
```
 Installation
```
pip install CCRS
```

## Example
```
import pickle
import scipy.stats as st
import pandas as pd
import numpy as np
import CCRS
result = CCR(your_data)
```











